ItemLabel<T> typedef
ItemLabel<T> =
String Function(T item)
Converts an item into the display label shown in the field and list.
Implementation
typedef ItemLabel<T> = String Function(T item);
Converts an item into the display label shown in the field and list.
typedef ItemLabel<T> = String Function(T item);