DropdownBehavior class
Configures interactive behavior for the dropdown experience.
Constructors
Properties
- autofocusSearch → bool
-
Whether the search input should request focus when opened.
final
- clearable → bool
-
Whether the selected value can be cleared from the field.
final
- closeOnSelect → bool
-
Whether the dropdown closes immediately after an item is selected.
final
- enableAnimations → bool
-
Whether built-in animations are enabled for the dropdown UI.
final
- enableSearch → bool
-
Whether the search field is shown in the dropdown UI.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited